@@ -33,6 +33,16 @@ def isnan(a: Numeric):
     return np.isnan(a)
 
 
+@dispatch
+def real(a: Numeric):
+    return np.real(a)
+
+
+@dispatch
+def imag(a: Numeric):
+    return np.imag(a)
+
+
 @dispatch
 def device(a: NPNumeric):
     return "cpu"
