@@ -4,10 +4,17 @@ import numpy as np
 from plum.type import VarArgs
 
 from . import dispatch, B
-from .types import DType, Int, Numeric
+from .types import DType, Int, Numeric, RandomState
 from .util import abstract
 
-__all__ = ["set_random_seed", "rand", "randn", "choice"]
+__all__ = [
+    "set_random_seed",
+    "create_random_state",
+    "global_random_state",
+    "rand",
+    "randn",
+    "choice",
+]
 
 
 @dispatch
@@ -33,8 +40,45 @@ def set_random_seed(seed: Int):
         torch.manual_seed(seed)
 
     # Set seed for JAX, if it is loaded.
-    if "jax" in sys.modules:
-        B.jax_rng.set_seed(seed)
+    if hasattr(B, "jax_global_random_state"):
+        import jax
+
+        B.jax_global_random_state = jax.random.PRNGKey(seed=seed)
+
+
+@dispatch
+@abstract()
+def create_random_state(dtype: DType, seed: Int = 0):
+    """Create a random state.
+
+    Args:
+        dtype (dtype): Data type of the desired framework to create a random state
+            for.
+        seed (int, optional): Seed to initialise the random state with. Defaults
+            to `0`.
+
+    Returns:
+        random state: Random state.
+    """
+
+
+@dispatch
+@abstract()
+def global_random_state(dtype: DType):
+    """Get the global random state.
+
+    Args:
+        dtype (dtype): Data type of the desired framework for which to get the global
+            random state.
+
+    Returns:
+        random state: Global random state.
+    """
+
+
+@dispatch
+def global_random_state(a):
+    return global_random_state(B.dtype(a))
 
 
 @dispatch
@@ -56,6 +100,11 @@ def rand(*shape: Int):
     return rand(B.default_dtype, *shape)
 
 
+@dispatch
+def rand(state: RandomState, ref: Numeric):
+    return rand(state, B.dtype(ref), *B.shape(ref))
+
+
 @dispatch
 def rand(ref: Numeric):
     return rand(B.dtype(ref), *B.shape(ref))
@@ -63,10 +112,11 @@ def rand(ref: Numeric):
 
 @dispatch
 @abstract()
-def randn(dtype: DType, *shape: Int):  # pragma: no cover
+def randn(state: RandomState, dtype: DType, *shape: Int):  # pragma: no cover
     """Construct a N(0, 1) random tensor.
 
     Args:
+        state (random state, optional): Random state.
         dtype (dtype, optional): Data type. Defaults to the default data type.
         *shape (shape, optional): Shape of the tensor. Defaults to `()`.
 
@@ -80,6 +130,11 @@ def randn(*shape: Int):
     return randn(B.default_dtype, *shape)
 
 
+@dispatch
+def randn(state: RandomState, ref: Numeric):
+    return randn(state, B.dtype(ref), *B.shape(ref))
+
+
 @dispatch
 def randn(ref: Numeric):
     return randn(B.dtype(ref), *B.shape(ref))
@@ -87,18 +142,24 @@ def randn(ref: Numeric):
 
 @dispatch
 @abstract()
-def choice(a: Numeric, n: Int):
+def choice(state: RandomState, a: Numeric, n: Int):  # pragma: no cover
     """Randomly choose from a tensor *with* replacement.
 
     Args:
+        state (random state, optional): Random state.
         a (tensor): Tensor to choose from.
         n (int, optional): Number of samples. Defaults to `1`.
 
     Returns:
-        tensor: Samples.
+        tensor: Choices.
     """
 
 
+@dispatch
+def choice(state: RandomState, a: Numeric):
+    return choice(state, a, 1)
+
+
 @dispatch
 def choice(a: Numeric):
     return choice(a, 1)
