@@ -44,6 +44,17 @@ def isnan(a: Numeric):
     return tf.math.is_nan(a)
 
 
+@dispatch
+def real(a: Numeric):
+    return tf.math.real(a)
+
+
+@dispatch
+def imag(a: Numeric):
+    return tf.math.imag(a)
+
+
+
 @dispatch
 def device(a: TFNumeric):
     return a.device
