@@ -58,6 +58,12 @@ def svd(a: Numeric, compute_uv: bool = True):
     return (u, s, v) if compute_uv else s
 
 
+@dispatch
+def eig(a: Numeric, compute_eigvecs: bool = True):
+    vals, vecs = torch.linalg.eig(a)
+    return (vals, vecs) if compute_eigvecs else vals
+
+
 @dispatch
 def solve(a: Numeric, b: Numeric):
     return torch.linalg.solve(a, b)
